diff src/screen.c @ 3250:927c7377cf49 v7.3.394

updated for version 7.3.394 Problem: When placing a mark while starting up a screen redraw messes up the screen. (lith) Solution: Don't redraw while still starting up. (Christian Brabandt)
author Bram Moolenaar <bram@vim.org>
date Tue, 10 Jan 2012 12:42:09 +0100
parents b6af1c5dd22f
children 320cc46d0eb0
line wrap: on
line diff
--- a/src/screen.c
+++ b/src/screen.c
@@ -764,9 +764,13 @@ update_debug_sign(buf, lnum)
 	    doit = TRUE;
     }
 
-    /* Return when there is nothing to do or screen updating already
-     * happening. */
-    if (!doit || updating_screen)
+    /* Return when there is nothing to do, screen updating is already
+     * happening (recursive call) or still starting up. */
+    if (!doit || updating_screen
+#ifdef FEAT_GUI
+	    || gui.starting
+#endif
+	    || starting)
 	return;
 
     /* update all windows that need updating */